@@ -7,9 +7,9 @@ use Role::Basic 'with';
 with 'Brickyard::Role::PluginBundle';
 
 sub bundle_config {
-    [   [ '@Default/Uppercase', $_[0]->_exp('Uppercase'), {} ],
-        [ '@Default/Repeat',   $_[0]->_exp('Repeat'), { times => 3 } ],
-        [ '@Default/Reporter', $_[0]->_exp('Reporter'), {} ],
+    [   [ '@Default/Uppercase', 'Uppercase', {} ],
+        [ '@Default/Repeat',   'Repeat',   { times => 3 } ],
+        [ '@Default/Reporter', 'Reporter', {} ],
     ];
 }
 1;
